@@ -195,11 +195,8 @@ gdl_dock_paned_create_child (GdlDockPaned   *paned,
         gtk_widget_unparent (GTK_WIDGET (item->child));
     
     /* create the container paned */
-    if (orientation == GTK_ORIENTATION_HORIZONTAL)
-        item->child = gtk_hpaned_new ();
-    else
-        item->child = gtk_vpaned_new ();
-    
+    item->child = gtk_paned_new (orientation);
+
     /* get notification for propagation */
     g_signal_connect (item->child, "notify::position",
                       (GCallback) gdl_dock_paned_notify_cb, (gpointer) item);
@@ -560,10 +557,10 @@ gdl_dock_paned_dock (GdlDockObject    *object,
     switch (GDL_DOCK_ITEM (object)->orientation) {
         case GTK_ORIENTATION_HORIZONTAL:
             if (!child1 && position == GDL_DOCK_LEFT) {
-                gtk_paned_pack1 (paned, GTK_WIDGET (requestor), FALSE, FALSE);
+                gtk_paned_pack1 (paned, GTK_WIDGET (requestor), TRUE, TRUE);
                 done = TRUE;
             } else if (!child2 && position == GDL_DOCK_RIGHT) {
-                gtk_paned_pack2 (paned, GTK_WIDGET (requestor), TRUE, FALSE);
+                gtk_paned_pack2 (paned, GTK_WIDGET (requestor), FALSE, FALSE);
                 done = TRUE;
             }
             break;
